@@ -491,14 +491,15 @@ SEXP ALIKEC_lang_alike_core(
 
   // Determine if it is a formular or not
 
-  SEXP class = getAttrib(target, R_ClassSymbol);
+  SEXP class = PROTECT(getAttrib(target, R_ClassSymbol));
   if(
     class != R_NilValue && TYPEOF(class) == STRSXP &&
-    !strcmp("formula", CHAR(asChar(STRING_ELT(class, XLENGTH(class) - 1)))) &&
+    !strcmp("formula", CHAR(STRING_ELT(class, XLENGTH(class) - 1))) &&
     CAR(target) == ALIKEC_SYM_tilde
   ) {
     formula = 1;
   }
+  UNPROTECT(1);
   // Check if alike; originally we would modify a copy of current, which is
   // why we send curr_cpy_par
 
